# Kernel

```{toctree}
:caption: Kernel objects
:maxdepth: 1

kernel/cae_display_preferences
kernel/input
kernel/kernel
kernel/messaging
kernel/table_collection
kernel/text_representation
kernel/utility
```
